<?php

namespace Materials\Material\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Materials\Material\Interfaces\MaterialRepositoryInterface;

class MaterialController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Materials\Material\Interfaces\MaterialRepositoryInterface $material
     *
     * @return type
     */
    public function __construct(MaterialRepositoryInterface $material)
    {
        $this->middleware('web');
        $this->setupTheme(config('theme.themes.public.theme'), config('theme.themes.public.layout'));

        $this->repository = $material;
        parent::__construct();
    }

    /**
     * Show material's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $materials = $this->repository
            ->pushCriteria(new \Materials\Material\Repositories\Criteria\MaterialPublicCriteria())
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        return $this->theme->of('material::public.material.index', compact('materials'))->render();
    }

    /**
     * Show material.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $material = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->theme->of('material::public.material.show', compact('material'))->render();
    }
}
